@@ -1,10 +1,9 @@
-from pandas.io.excel._openpyxl import OpenpyxlReader
+
 from pandas import ExcelFile
-from pandas._typing import (
-    FilePathOrBuffer,
-    StorageOptions,
-    DtypeArg
-)
+from pandas._typing import StorageOptions
+from engines._openpyxl import OpenpyxlLimitedReader
+from engines._pyxlsb import PyxlsbLimitedReader
+from engines._xlrd import XlrdLimitedReader
 
 # TODO: Implementar parâmetros first_rows e last_rows - 1.2.0
 
@@ -41,7 +40,7 @@ def read_excel(
     should_close = False
     if not isinstance(io, RowLimitedExcelFile):
         should_close = True
-        io = RowLimitedExcelFile(io, storage_options=storage_options, engine="row_limited", max_rows=max_rows)
+        io = RowLimitedExcelFile(io, storage_options=storage_options, engine=engine, max_rows=max_rows)
     elif engine and engine != io.engine:
         raise ValueError(
             "Engine should not be specified when passing "
@@ -89,55 +88,16 @@ def read_excel(
 
 
 class RowLimitedExcelFile(ExcelFile):
-    def __init__(self, path_or_buffer, engine="row_limited", storage_options: StorageOptions = None, max_rows=None):
+    def __init__(self, path_or_buffer, engine=None, storage_options: StorageOptions = None, max_rows=None):
         self.max_rows = max_rows
-        self._engines.update({"row_limited": RowLimitedReader})
+        self._engines.update(
+            {
+                "openpyxl": OpenpyxlLimitedReader,
+                "pyxlsb": PyxlsbLimitedReader,
+                "xlrd": XlrdLimitedReader,
+            }
+        )
+
         super().__init__(path_or_buffer, engine, storage_options)
-        self._reader = self._engines[engine](self._io, storage_options=storage_options, max_rows=self.max_rows)
-        return
-
-
-class RowLimitedReader(OpenpyxlReader):
-
-    def __init__(self, filepath_or_buffer: FilePathOrBuffer, storage_options: StorageOptions = None, max_rows=None) -> None:
-        self.max_rows = max_rows
-        super().__init__(filepath_or_buffer, storage_options=storage_options)
-
-    def get_sheet_data(self, sheet, convert_float: bool):
-        if self.book.read_only:
-            sheet.reset_dimensions()
-
-        data: list[list[Scalar]] = []
-        last_row_with_data = -1
-
-        rows_enumerate = enumerate(sheet.rows)
-        rows_list = []
-        if self.max_rows is None:
-            rows_list = list(enumerate(sheet.rows))
-        else:
-            for i in range(self.max_rows + 1):
-                try:
-                    rows_list.append(next(rows_enumerate))
-                except:
-                    break
-        for row in rows_list:
-            converted_row = [self._convert_cell(cell, convert_float) for cell in row[1]]
-            while converted_row and converted_row[-1] == "":
-                # trim trailing empty elements
-                converted_row.pop()
-            if converted_row:
-                last_row_with_data = row[0]
-            data.append(converted_row)
-        
-        # Trim trailing empty rows
-        data = data[: last_row_with_data + 1]
-        if len(data) > 0:
-            # extend rows to max width
-            max_width = max(len(data_row) for data_row in data)
-            if min(len(data_row) for data_row in data) < max_width:
-                empty_cell: list[Scalar] = [""]
-                data = [
-                    data_row + (max_width - len(data_row)) * empty_cell
-                    for data_row in data
-                ]
-        return data
\ No newline at end of file
+        self._reader = self._engines[self.engine](self._io, storage_options=storage_options, max_rows=self.max_rows)
+        return
\ No newline at end of file
